@@ -106,7 +106,7 @@ def end_interceptor(thread_id=None, ctx= None):
     ctx.start_time = start_time
 
     datas = [ctx.host, ctx.service_name, ctx.mtid, ctx.mdepth, ctx.mcaller_txid,
-             ctx.mcaller_pcode, ctx.mcaller_spec, ctx.mcaller_url]
+             ctx.mcaller_pcode, ctx.mcaller_spec, ctx.mcaller_url, ctx.mcaller_poid]
     ctx.elapsed = DateUtil.nowSystem() - start_time
 
     UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
@@ -147,6 +147,12 @@ def interceptor(rn_environ, *args, **kwargs):
             conf._trace_mtrace_callee_key.upper().replace('-', '_')), '')
         if myid:
             ctx.setTxid(myid)
+    caller_poid = environ.get('HTTP_{}'.format(
+        conf._trace_mtrace_caller_poid_key.upper().replace('-', '_')), '')
+    
+    if caller_poid:
+        ctx.mcaller_poid = caller_poid
+
     start_interceptor(ctx)
     
     callback = fn(*args, **kwargs)
@@ -212,9 +218,11 @@ def interceptor_error(status_code, errors):
         UdpSession.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
 
 
-def interceptor_step_error(e):
-    print('interceptor_step_error', e)
-    ctx = TraceContextManager.getLocalContext()
+def interceptor_step_error(e, ctx = None):
+    if not ctx:
+        ctx = TraceContextManager.getLocalContext()
+    if not ctx:
+        return
     ctx.error_step = e
     if not ctx.error:
         ctx.error = 1
@@ -261,15 +269,18 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
     ctx.start_time = start_time
     ctx.httpc_url = httpc_url
     ctx.active_httpc_hash = ctx.httpc_url
-    
+
     try:
-        callback = fn(*args, **kwargs)
-        return callback
+        try:
+            callback = fn(*args, **kwargs)
+            return callback
+        except TypeError as e:
+            callback = fn(*args)
+            return callback
     except Exception as e:
-        interceptor_step_error(e)
-        print('interceptor_httpc_request', e)
+        interceptor_step_error(e, ctx = ctx)
     finally:
-        ctx = TraceContextManager.getLocalContext()
+        #ctx = TraceContextManager.getLocalContext()
         datas = [ctx.httpc_url, ctx.mcallee]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         UdpSession.send_packet(PacketTypeEnum.TX_HTTPC, ctx, datas)
@@ -297,8 +308,7 @@ def interceptor_sock_connect(fn, *args, **kwargs):
         callback = fn(*args, **kwargs)
         return callback
     except Exception as e:
-        interceptor_step_error(e)
-        print('interceptor_sock_connect', e)
+        interceptor_step_error(e)        
     finally:
         ctx.socket_connecting = False
 
@@ -478,10 +488,10 @@ def inter_tx_trace_auto_on(ctx):
 
 def transfer(headers):
     ctx = TraceContextManager.getLocalContext()
-    
+
     if not ctx.mtid:
         inter_tx_trace_auto_on(ctx)
-    
+
     if ctx.mtid:
         headers[conf._trace_mtrace_caller_key] = ctx.transfer()
         if conf.stat_mtrace_enabled:
@@ -489,4 +499,5 @@ def transfer(headers):
 
         ctx.mcallee = TraceContextManager.getId()
         headers[conf._trace_mtrace_callee_key] = Hexa32.toString32(ctx.mcallee)
+        headers[conf._trace_mtrace_caller_poid_key] = ctx.transferPOID()
     return headers
